from distutils.core import setup

setup(
    name='fan',
    packages=['fan'],
    version='0.1.0',
    description='microservices kit',
    author='cybergrind',
    author_email='cybergrind@gmail.com',
    keywords=['rpc', 'microservices'],
    classifiers=[],
)
